declare namespace cn {
    namespace nukkit {
        namespace plugin {
            // @ts-ignore
            interface Plugin extends cn.nukkit.command.CommandExecutor {
                /**
                 * 在一个Nukkit插件被加载时调用的方法。这个方法会在{@link Plugin#onEnable()}之前调用。<br>
                 * Called when a Nukkit plugin is loaded, before {@link Plugin#onEnable()} .
                 * <p>应该填写加载插件时需要作出的动作。例如：初始化数组、初始化数据库连接。<br>
                 * Use this to init a Nukkit plugin, such as init arrays or init database connections.</p>
                 */
                // @ts-ignore
                 onLoad(): void;
                /**
                 * 在一个Nukkit插件被启用时调用的方法。<br>
                 * Called when a Nukkit plugin is enabled.
                 * <p>应该填写插件启用时需要作出的动作。例如：读取配置文件、读取资源、连接数据库。<br>
                 * Use this to open config files, open resources, connect databases.</p>
                 * <p>注意到可能存在的插件管理器插件，这个方法在插件多次重启时可能被调用多次。<br>
                 * Notes that there may be plugin manager plugins,
                 * this method can be called many times when a plugin is restarted many times.</p>
                 */
                // @ts-ignore
                 onEnable(): void;
                /**
                 * 返回这个Nukkit插件是否已启用。<br>
                 * Whether this Nukkit plugin is enabled.
                 */
                // @ts-ignore
                 isEnabled(): boolean;
                /**
                 * 在一个Nukkit插件被停用时调用的方法。<br>
                 * Called when a Nukkit plugin is disabled.
                 * <p>应该填写插件停用时需要作出的动作。例如：关闭数据库，断开资源。<br>
                 * Use this to free open things and finish actions,
                 * such as disconnecting databases and close resources.</p>
                 * <p>注意到可能存在的插件管理器插件，这个方法在插件多次重启时可能被调用多次。<br>
                 * Notes that there may be plugin manager plugins,
                 * this method can be called many times when a plugin is restarted many times.</p>
                 */
                // @ts-ignore
                 onDisable(): void;
                /**
                 * 返回这个Nukkit插件是否已停用。<br>
                 * Whether this Nukkit plugin is disabled.
                 */
                // @ts-ignore
                 isDisabled(): boolean;
                /**
                 * 返回这个Nukkit插件的数据文件夹。<br>
                 * The data folder of this Nukkit plugin.
                 * <p>一般情况下，数据文件夹名字与插件名字相同，而且都放在nukkit安装目录下的plugins文件夹里。<br>
                 * Under normal circumstances, the data folder has the same name with the plugin,
                 * and is placed in the 'plugins' folder inside the nukkit installation directory.</p>
                 */
                // @ts-ignore
                 getDataFolder(): java.io.File;
                /**
                 * 返回描述这个Nukkit插件的{@link PluginDescription}对象。<br>
                 * The description this Nukkit plugin as a {@link PluginDescription} object.
                 * <p>对于jar格式的Nukkit插件，插件的描述在plugin.yml文件内定义。<br>
                 * For jar-packed Nukkit plugins, the description is defined in the 'plugin.yml' file.</p>
                 */
                // @ts-ignore
                 getDescription(): cn.nukkit.plugin.PluginDescription;
                /**
                 * 读取这个插件特定的资源文件，并返回为{@code InputStream}对象。<br>
                 * Reads a resource of this plugin, and returns as an {@code InputStream} object.
                 * <p>对于jar格式的Nukkit插件，Nukkit会在jar包内的资源文件夹(一般为resources文件夹)寻找资源文件。<br>
                 * For jar-packed Nukkit plugins, Nukkit will look for your resource file in the resources folder,
                 * which is normally named 'resources' and placed in plugin jar file.</p>
                 * <p>当你需要把一个文件的所有内容读取为字符串，可以使用{@link cn.nukkit.utils.Utils#readFile}函数，
                 * 来从{@code InputStream}读取所有内容为字符串。例如：<br>
                 * When you need to read the whole file content as a String, you can use {@link cn.nukkit.utils.Utils#readFile}
                 * to read from a {@code InputStream} and get whole content as a String. For example:</p>
                 * <p><code>String string = Utils.readFile(this.getResource("string.txt"));</code></p>
                 */
                // @ts-ignore
                 getResource(filename: string): java.io.InputStream;
                /**
                 * 保存这个Nukkit插件的资源。<br>
                 * Saves the resource of this plugin.
                 * <p>对于jar格式的Nukkit插件，Nukkit会在jar包内的资源文件夹寻找资源文件，然后保存到数据文件夹。<br>
                 * For jar-packed Nukkit plugins, Nukkit will look for your resource file in the resources folder,
                 * which is normally named 'resources' and placed in plugin jar file, and copy it into data folder.</p>
                 * <p>这个函数通常用来在插件被加载(load)时，保存默认的资源文件。这样插件在启用(enable)时不会错误读取空的资源文件，
                 * 用户也无需从开发者处手动下载资源文件后再使用插件。<br>
                 * This is usually used to save the default plugin resource when the plugin is LOADED .If this is used,
                 * it won't happen to load an empty resource when plugin is ENABLED, and plugin users are not required to get
                 * default resources from the developer and place it manually. </p>
                 * <p>如果需要替换已存在的资源文件，建议使用{@link cn.nukkit.plugin.Plugin#saveResource(String, boolean)}<br>
                 * If you need to REPLACE an existing resource file, it's recommended
                 * to use {@link cn.nukkit.plugin.Plugin#saveResource(String, boolean)}.</p>
                 */
                // @ts-ignore
                 saveResource(filename: string): boolean;
                /**
                 * 保存或替换这个Nukkit插件的资源。<br>
                 * Saves or replaces the resource of this plugin.
                 * <p>对于jar格式的Nukkit插件，Nukkit会在jar包内的资源文件夹寻找资源文件，然后保存到数据文件夹。<br>
                 * For jar-packed Nukkit plugins, Nukkit will look for your resource file in the resources folder,
                 * which is normally named 'resources' and placed in plugin jar file, and copy it into data folder.</p>
                 * <p>如果需要保存默认的资源文件，建议使用{@link cn.nukkit.plugin.Plugin#saveResource(String)}<br>
                 * If you need to SAVE DEFAULT resource file, it's recommended
                 * to use {@link cn.nukkit.plugin.Plugin#saveResource(String)}.</p>
                 */
                // @ts-ignore
                 saveResource(filename: string, replace: boolean): boolean;
                // @ts-ignore
                 saveResource(filename: string, outputName: string, replace: boolean): boolean;
                /**
                 * 返回这个Nukkit插件配置文件的{@link cn.nukkit.utils.Config}对象。<br>
                 * The config file this Nukkit plugin as a {@link cn.nukkit.utils.Config} object.
                 * <p>一般地，插件的配置保存在数据文件夹下的config.yml文件。<br>
                 * Normally, the plugin config is saved in the 'config.yml' file in its data folder.</p>
                 */
                // @ts-ignore
                 getConfig(): cn.nukkit.utils.Config;
                /**
                 * 保存这个Nukkit插件的配置文件。<br>
                 * Saves the plugin config.
                 */
                // @ts-ignore
                 saveConfig(): void;
                /**
                 * 保存这个Nukkit插件的默认配置文件。<br>
                 * Saves the DEFAULT plugin config.
                 * <p>执行这个函数时，Nukkit会在资源文件夹内寻找开发者配置好的默认配置文件config.yml，然后保存在数据文件夹。
                 * 如果数据文件夹已经有一个config.yml文件，Nukkit不会替换这个文件。<br>
                 * When this is used, Nukkit will look for the default 'config.yml' file which is configured by plugin developer
                 * and save it to the data folder. If a config.yml file exists in the data folder, Nukkit won't replace it.</p>
                 * <p>这个函数通常用来在插件被加载(load)时，保存默认的配置文件。这样插件在启用(enable)时不会错误读取空的配置文件，
                 * 用户也无需从开发者处手动下载配置文件保存后再使用插件。<br>
                 * This is usually used to save the default plugin config when the plugin is LOADED .If this is used,
                 * it won't happen to load an empty config when plugin is ENABLED, and plugin users are not required to get
                 * default config from the developer and place it manually. </p>
                 */
                // @ts-ignore
                 saveDefaultConfig(): void;
                /**
                 * 重新读取这个Nukkit插件的默认配置文件。<br>
                 * Reloads the plugin config.
                 * <p>执行这个函数时，Nukkit会从数据文件夹中的config.yml文件重新加载配置。
                 * 这样用户在调整插件配置后，无需重启就可以马上使用新的配置。<br>
                 * By using this, Nukkit will reload the config from 'config.yml' file, then it isn't necessary to restart
                 * for plugin user who changes the config and needs to use new config at once.</p>
                 */
                // @ts-ignore
                 reloadConfig(): void;
                /**
                 * 返回运行这个插件的服务器的{@link cn.nukkit.Server}对象。<br>
                 * Gets the server which is running this plugin, and returns as a {@link cn.nukkit.Server} object.
                 */
                // @ts-ignore
                 getServer(): cn.nukkit.Server;
                /**
                 * 返回这个插件的名字。<br>
                 * Returns the name of this plugin.
                 * <p>Nukkit会从已经读取的插件描述中获取插件的名字。<br>
                 * Nukkit will read plugin name from plugin description.</p>
                 */
                // @ts-ignore
                 getName(): string;
                /**
                 * 返回这个插件的日志记录器为{@link cn.nukkit.plugin.PluginLogger}对象。<br>
                 * Returns the logger of this plugin as a {@link cn.nukkit.plugin.PluginLogger} object.
                 * <p>使用日志记录器，你可以在控制台和日志文件输出信息。<br>
                 * You can use a plugin logger to output messages to the console and log file.</p>
                 */
                // @ts-ignore
                 getLogger(): cn.nukkit.plugin.PluginLogger;
                /**
                 * 返回这个插件的加载器为{@link cn.nukkit.plugin.PluginLoader}对象。<br>
                 * Returns the loader of this plugin as a {@link cn.nukkit.plugin.PluginLoader} object.
                 */
                // @ts-ignore
                 getPluginLoader(): cn.nukkit.plugin.PluginLoader;
            }
        }
    }
}
